// Get the form and inputs like first name, last name, email
const form = document.getElementById('contactForm');
const firstName = document.getElementById('firstName');
const lastName = document.getElementById('lastName');
const email = document.getElementById('email');
const linkedin = document.getElementById('linkedin');
const meet = document.getElementById('meet');
const other = document.getElementById('other');
const addMeCheckbox = document.getElementById('addMe');
const emailFormatSection = document.querySelector('.email-format');

// Handle form submission
form.addEventListener('submit', function (e) {
    let isValid = true;  // Assume the form is correct 

    // Check if the first name and last name are filled in
    if (firstName.value === '') {
        document.getElementById('firstNameError').classList.remove('hidden');
        isValid = false;
    } else {
        document.getElementById('firstNameError').classList.add('hidden');
    }

    if (lastName.value === '') {
        document.getElementById('lastNameError').classList.remove('hidden');
        isValid = false;
    } else {
        document.getElementById('lastNameError').classList.add('hidden');
    }

    // Validate email if provided
    if (email.value !== '') {
        const emailPattern = /^[^\s@]+@[^\s@]+\.[^\s@]+$/;
        if (!emailPattern.test(email.value)) {
            document.getElementById('emailError').classList.remove('hidden');
            isValid = false;
        } else {
            document.getElementById('emailError').classList.add('hidden');
        }
    }

    // Check if LinkedIn URL is valid if provided
    if (linkedin.value !== '' && !linkedin.value.startsWith('https://linkedin.com/in/')) {
        document.getElementById('linkedinError').classList.remove('hidden');
        isValid = false;
    } else {
        document.getElementById('linkedinError').classList.add('hidden');
    }

    // Ensure a "How we met" option is selected
    if (meet.value === '' || meet.value === 'Please') {
        document.getElementById('meetError').classList.remove('hidden');
        isValid = false;
    } else {
        document.getElementById('meetError').classList.add('hidden');
    }

    // Redirect if the form is valid
    if (isValid) {
        e.preventDefault();
        window.location.href = 'thank-you.html';
    } else {
        e.preventDefault();  // Prevent submission if invalid
    }
});

// Handle showing/hiding the "Other" field when "Other" is selected in the dropdown
meet.addEventListener('change', function () {
    if (meet.value === 'Other') {
        other.classList.remove('hidden');
    } else {
        other.classList.add('hidden');
    }
});

// Show or hide email format options when the mailing list checkbox is clicked
addMeCheckbox.addEventListener('change', function () {
    if (addMeCheckbox.checked) {
        emailFormatSection.classList.remove('hidden');
    } else {
        emailFormatSection.classList.add('hidden');
    }
});
